/*
 * Created 11/26/2014 to test MRDataSource 
 *
 */

/** MRDStest
  * 
  * Read all resolutions of an MRDataSource and print out the
  * bounds of each resolution.
  * 
  * @author rdb
  */
import java.util.ArrayList;
import java.io.*;
import edu.unh.sdb.common.*;
import edu.unh.sdb.datasource.*;

public class MRDStest
{
    private static String     inName  = null; // input descr file
    
    //------------------------------- main ---------------------------------
    public static void main( String[] args )
    {
        MRDataSource   ds = null;  // the original data source
        readArgs( args );
        
        Log.init( "Granite-errors", Log.LogToFile | Log.LogToStdErr );
        SDBError.setErrorReportingLevel( SDBError.AlwaysThrow );
        
        ds = (MRDataSource) openDataSource( "MRDStest", inName );  
        ds.activate(); 
        
        ISBounds bnds = ds.getBounds();
        System.out.println( "R0 bounds: " + bnds );
        System.out.println( "-------- going down --------- " );
        while ( ds.coarser() )
        {
            int level = ds.getLevel();
            bnds = ds.getBounds();
            System.out.println( "R" + level + " bounds: " + bnds );
        }
        System.out.println( "++++++++ going up +++++++++++ " );
        while ( ds.finer() )
        {
            int level = ds.getLevel();
            bnds = ds.getBounds();
            System.out.println( "R" + level + " bounds: " + bnds );
        }
    }
    
    //---------------------- openDataSource ----------------------------
    // a little utility function to read the descriptor file.
    //
    private static DataSource openDataSource( String dsName, String fileName )
    {
        DataSource ds = null;
        try 
        {
            ds = DataSource.create( dsName, inName );
        } catch ( Exception ex )
        {
            System.err.println( "Open error: " + ex.getMessage() );
            System.exit( -1 );
        }
        return ds;
    }
    
    
    //--------------- usage -----------------------------------
    static void usage()
    {
        PrintStream out = System.out; // should pass in output stream
        
        out.println( "Usage: java MRDStest mrfdl " );
        out.println( "    mrfdl - xfdl file describing MRDataSource" );
    }
    
    //-------------- readArgs --------------------------------
    //
    static void readArgs( String[] args )
    {  
        if ( args.length == 0 )
        {
            usage();
            System.exit( 0 );
        }
        inName = args[ 0 ];
    }
}
